<?php

final class ITSEC_Malware_Scheduling_Settings_Page extends ITSEC_Module_Settings_Page {
	private $version = 1;

	public function __construct() {
		ITSEC_Lib::load( 'feature-flags' );

		$this->id          = 'malware-scheduling';
		$this->title       = ITSEC_Lib_Feature_Flags::is_enabled( 'site_scanner' ) ? __( 'Site Scan Scheduling', 'it-l10n-ithemes-security-pro' ) : __( 'Malware Scan Scheduling', 'it-l10n-ithemes-security-pro' );
		$this->description = __( 'Protect your site with automated site scans. When this feature is enabled, the site will be automatically scanned each day. If a problem is found, an email is sent to select users.', 'it-l10n-ithemes-security-pro' );
		$this->type        = 'recommended';
		$this->pro         = true;

		if ( ITSEC_Lib_Feature_Flags::is_enabled( 'site_scanner' ) ) {
			$this->documentation = 'https://help.ithemes.com/hc/en-us/articles/360046334433';
		}

		parent::__construct();
	}

	public function enqueue_scripts_and_styles() {
		wp_enqueue_style( 'itsec-malware-scheduling-admin-style', plugins_url( 'css/settings-page.css', __FILE__ ), array(), $this->version );
	}

	protected function render_description( $form ) {
		if ( ITSEC_Lib_Feature_Flags::is_enabled( 'site_scanner' ) ) {
			$description = __( 'This site scan is powered by iThemes. We use several datapoints to check for known malware, blacklisting status, website errors and out-of-date software. These datapoints are not 100% accurate, but we try our best to provide thorough results.', 'it-l10n-ithemes-security-pro' );
			$module      = 'site-scanner';
		} else {
			$description = sprintf( __( 'This malware scan is powered by <a href="%s">Sucuri SiteCheck</a>. It checks for known malware, blacklisting status, website errors and out-of-date software. Although the Sucuri team does its best to provide thorough results, 100%% accuracy is not realistic and is not guaranteed.', 'it-l10n-ithemes-security-pro' ), esc_url( 'https://ithemes.com/sitecheck' ) );
			$module      = 'malware';
		}
		?>
		<p><?php echo $description; ?></p>
		<p><?php printf( __( 'Results of previous scans can be found on the <a href="%s">logs page</a>.', 'it-l10n-ithemes-security-pro' ), ITSEC_Core::get_logs_page_url( $module ) ); ?></p>
		<?php

	}

	protected function render_settings( $form ) {

	}
}

new ITSEC_Malware_Scheduling_Settings_Page();
